<?php
/*
Plugin Name: Taxa de Pagamento à Cobrança - Portugal
Description: Adiciona uma taxa ao carrinho quando o cliente seleciona o pagamento à cobrança para Portugal. Personalizável pelo menu de administração.
Version: 1.1
Author: Cubo Mágico Design
*/

if (!defined('ABSPATH')) {
    exit; // Evitar acesso direto
}

// Adiciona o menu de configuração ao painel de administração
function taxa_cobranca_menu() {
    add_menu_page(
        'Configurações de Taxa de Pagamento à Cobrança',
        'Taxa à Cobrança',
        'manage_options',
        'taxa-cobranca-config',
        'taxa_cobranca_config_page',
        'dashicons-admin-generic',
        56
    );
}
add_action('admin_menu', 'taxa_cobranca_menu');

// Função para renderizar a página de configurações
function taxa_cobranca_config_page() {
    if (isset($_POST['taxa_cobranca_valor'])) {
        update_option('taxa_cobranca_valor', sanitize_text_field($_POST['taxa_cobranca_valor']));
        echo '<div class="updated"><p>Taxa atualizada com sucesso!</p></div>';
    }

    $taxa = get_option('taxa_cobranca_valor', 3.00); // Valor padrão de 3€

    echo '<div class="wrap">
        <h1>Configurações de Taxa de Pagamento à Cobrança</h1>
        <form method="post">
            <table class="form-table">
                <tr valign="top">
                <th scope="row">Valor da Taxa (€)</th>
                <td><input type="number" step="0.01" name="taxa_cobranca_valor" value="' . esc_attr($taxa) . '" /></td>
                </tr>
            </table>
            <p class="submit"><input type="submit" class="button-primary" value="Guardar Alterações" /></p>
        </form>
    </div>';
}

// Adiciona a taxa de cobrança ao carrinho
function adicionar_taxa_pagamento_cobranca($cart) {
    if (is_admin() || !is_checkout()) return;

    $chosen_payment_method = WC()->session->get('chosen_payment_method');
    $taxa = get_option('taxa_cobranca_valor', 3.00); // Padrão de 3€
    $pais = WC()->customer->get_billing_country();

    // Verifica se o método de pagamento é "pagamento à cobrança" e o país é Portugal
    if ($chosen_payment_method === 'cod' && $pais === 'PT') {
        $cart->add_fee(__('Taxa de Pagamento à Cobrança', 'woocommerce'), $taxa);
    }
}
add_action('woocommerce_cart_calculate_fees', 'adicionar_taxa_pagamento_cobranca', 10, 1);
